@@ -7,9 +7,18 @@ from random import randint
 from dataclasses_json import DataClassJsonMixin
 
 
-class JobType(Enum):
-  JOB_TYPE_TEXT_2_IMAGE = 0
-  JOB_TYPE_IMAGE_2_IMAGE = 1
+class JobType(str, Enum):
+  TEXT_2_IMAGE = "text2image"
+  IMAGE_2_IMAGE = "image2image"
+
+class JobState(str, Enum):
+  UNKNOWN = "unknown"
+  SUBMITTED = "submitted"
+  ACCEPTED = "accepted"
+  WORKING = "working"
+  FINISHED = "finished"
+  ERROR = "error"
+
 
 
 @dataclass
@@ -40,6 +49,7 @@ class ImageData(DataClassJsonMixin):
 @dataclass
 class JobStatus(DataClassJsonMixin):
   job_id: str
+  job_state: JobState
   progress_pct: float
   images: list[ImageData] = field(default_factory=list)
   image_uris: list[str] = field(default_factory=list)
@@ -57,7 +67,6 @@ class Image2ImageParams(DataClassJsonMixin):
 class Job(DataClassJsonMixin):
   id: str
   job_type: JobType
-
   prompt: str
   batch_size: int = 5
   size: ImageSize = ImageSize(512, 512)
